@@ -13,7 +13,7 @@ MCG_UPSTREAM_BRANCH="5.8"
 # Map of all the sidecars -- containers that we use but are not built by us
 declare -A SIDECAR_IMAGE
 SIDECAR_IMAGE=(
-    [rhceph]="registry.redhat.io/rhceph/rhceph-4-rhel8"
+    [rhceph]="registry-proxy.engineering.redhat.com/rh-osbs/rhceph"
     [csi-node-driver-registrar]="registry.redhat.io/openshift4/ose-csi-node-driver-registrar"
     [csi-external-resizer]="registry.redhat.io/openshift4/ose-csi-external-resizer"
     [csi-external-provisioner]="registry.redhat.io/openshift4/ose-csi-external-provisioner"
@@ -61,7 +61,7 @@ function get_oc_tool() {
     # For debug. Don't want to fail if we cannot login at this stage for some reason
     $OC_TOOL version || true
     $OC_TOOL project || true
-    $OC_TOOL project cpaas-rhocs || true
+    $OC_TOOL project cpaas-rhodf || true
 }
 
 function tag_to_sha() {
@@ -69,7 +69,7 @@ function tag_to_sha() {
     _TAG=$(echo $1 | rev | cut -d ':' -f 1 | rev)
 
     # Map OpenShift registry back to brew registry
-    _IMAGE=${_IMAGE/image-registry.openshift-image-registry.svc:5000\/cpaas-rhocs\/ocs4-/registry-proxy.engineering.redhat.com\/rh-osbs\/ocs4-}
+    _IMAGE=${_IMAGE/image-registry.openshift-image-registry.svc:5000\/cpaas-rhodf\/ocs4-/registry-proxy.engineering.redhat.com\/rh-osbs\/ocs4-}
 
     # Get the manifest digest SHA
     local _IMAGE_SHA=$(skopeo inspect --authfile .skopeo-auth.json "docker://$_IMAGE:$_TAG" | grep '"Digest":' | awk '{print $2}' | cut -d '"' -f 2)
